@@ -27,10 +27,10 @@ LuaHighlighter::LuaHighlighter(QObject* parent): DefaultHighlighter(parent)
     addKeywords ( luahelper_keywords()  );
     addVariables( luahelper_variables() );
 
-    addRule(QRegExp("[A-Za-z0-9_]+(?=\\()")    , functionFormat());
-    addRule(QRegExp("\".*\"")                  , stringFormat());
-    addRule(QRegExp("'.*'")                    , stringFormat());
-    addRule(QRegExp("--[^\n]*")                , commentFormat());
+    addRule(QRegExp(QLatin1String("[A-Za-z0-9_]+(?=\\()"))    , functionFormat());
+    addRule(QRegExp(QLatin1String("\".*\""))                  , stringFormat());
+    addRule(QRegExp(QLatin1String("'.*'"))                    , stringFormat());
+    addRule(QRegExp(QLatin1String("--[^\n]*"))                , commentFormat());
     // did not add support for the multiline comment or multiline string
 }
 
